@@ -1,4 +1,4 @@
 #! /usr/bin/env bash
 $EXTRACTRC `find . -name \*.rc -o -name \*.ui -o -name \*.kcfg` >> rc.cpp
-$XGETTEXT `find . -name \*.js -o -name \*.qml -o -name \*.cpp` -o $podir/plasmavault-kde.pot
+$XGETTEXT `find . -name \*.js -o -name \*.qml -o -name \*.cpp -o -name \*.h` -o $podir/plasmavault-kde.pot
 rm -f rc.cpp
