@@ -24,7 +24,7 @@ Backend::~Backend()
 
 QStringList Backend::availableBackends()
 {
-    return {"encfs", "cryfs", "gocryptfs"};
+    return {QStringLiteral("encfs"), QStringLiteral("cryfs"), QStringLiteral("gocryptfs")};
 }
 
 Backend::Ptr Backend::instance(const QString &backend)
@@ -41,7 +41,7 @@ QString Backend::formatMessageLine(const QString &command, const QPair<bool, QSt
     const auto valid = result.first;
     const auto message = result.second;
 
-    QString htmlMessage = (valid ? QString() : "<b>") + message + (valid ? QString() : "</b>") + "<br />\n";
+    QString htmlMessage = (valid ? QString() : QStringLiteral("<b>")) + message + (valid ? QString() : QStringLiteral("</b>")) + "<br />\n";
 
     return i18nc("formatting the message for a command, as in encfs: not found", "%1: %2", command, htmlMessage);
 }
