@@ -27,7 +27,7 @@ public:
     Q_DECLARE_FLAGS(Flags, Flag)
 
     DirectoryPairChooserWidget(Flags flags);
-    ~DirectoryPairChooserWidget();
+    ~DirectoryPairChooserWidget() override;
 
     PlasmaVault::Vault::Payload fields() const override;
     void init(const PlasmaVault::Vault::Payload &payload) override;
